@@ -12,7 +12,7 @@ FactoryGirl.define do
     end
 
     after(:create) do |u, evaluator|
-      u.confirm! if evaluator.confirm_account
+      u.confirm if evaluator.confirm_account
     end
 
     trait :with_reset_password_token do
@@ -21,6 +21,12 @@ FactoryGirl.define do
 
     trait :with_authentication_token do
       authentication_token { SecureRandom.hex }
+      authentication_token_created_at { Time.now }
+    end
+
+    trait :with_day_old_token do
+      authentication_token { SecureRandom.hex }
+      authentication_token_created_at { Time.now - 1.day }
     end
   end
 end
