@@ -1,6 +1,17 @@
 require 'spec_helper'
 
 describe Devise::TokenAuthenticatable do
+  context "configuring the token_expires_in" do
+    let(:expire_time) { 1.hour }
+
+    it "should set the configuration" do
+      expect {
+        Devise::TokenAuthenticatable.setup do |config|
+          config.token_expires_in = expire_time
+        end
+      }.to change { Devise::TokenAuthenticatable.token_expires_in }.from(nil).to(expire_time)
+    end
+  end
 
   context "configuring the token_authentication_key" do
     let(:new_key) { :other_key }
@@ -37,5 +48,4 @@ describe Devise::TokenAuthenticatable do
       }.to change { Devise::TokenAuthenticatable.should_ensure_authentication_token }.from(false).to(should_ensure)
     end
   end
-
 end
